@@ -1,6 +1,6 @@
 print ("!!!!!!!!!!!!!!!!!! Hello, to  a2connect !!!!!!!!!!!!!!!!!!!!!!")
-import mod1
-import mod2
+from a2connect import mod1
+from a2connect import mod2
 def hello():
     return "!!!!!!!!!!!!!!!!! Hello, world !!!!!!!!!!!!!!!!!!"
 x = mod1.shima
